izug.refegovservice
===================

izug.refegovservice provides one content type which describes a government service
and a further content type that can display the former elsewhere on the site by
reference.

Note that this product used to describe webservices (WDSL), but this feature
has been discontinued.


Compatibility
-------------

``izug.refegovservice`` is compatible with Plone 4.3 and Plone 5.1.


Usage
-----

Add ``izug.refegovservice`` to your buildout configuration:

::

  [instance]
  eggs =
      izug.refegovservice

- Run buildout

- Install ``izug.refegovservice`` (and optionally ``ftw.table``) in portal_setup


Copyright
---------

This package is copyright by `4teamwork <http://www.4teamwork.ch/>`_.

``izug.organisation`` is licensed under GNU General Public License, version 2.
